@@ -733,4 +733,4 @@ class LinkedListLRUCache:
     def popitem(self):
         i = self.last.me
         obj = self.remove(i[0])
-        return i
+        return obj
