@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 
-#  Copyright (c) 2002-2009 Zooko "Zooko" Wilcox-O'Hearn
+#  Copyright (c) 2002-2010 Zooko "Zooko" Wilcox-O'Hearn
 #  This file is part of pyutil; see README.txt for licensing terms.
 
-import random, sys, threading, time, traceback, types, unittest
+import random, unittest
 
-from pyutil.assertutil import _assert, precondition, postcondition
+from pyutil.assertutil import _assert
 
 from pyutil.humanreadable import hr
 from pyutil import memutil
-from pyutil.cache import *
+from pyutil import cache
 
 class Bencher:
     def __init__(self, klass, MAXREPS=2**8, MAXTIME=5):
@@ -91,14 +91,14 @@ class Bencher:
                 benchutil.rep_bench(f, BSIZE, self._generic_benchmarking_init, MAXREPS=self.MAXREPS, MAXTIME=self.MAXTIME)
 
 def quick_bench():
-    b = Bencher(LRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15, 2**16,))
-    b = Bencher(LinkedListLRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15,))
-    b = Bencher(SmallLRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15,))
+    Bencher(cache.LRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15, 2**16,))
+    Bencher(cache.LinkedListLRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15,))
+    Bencher(cache.SmallLRUCache, MAXTIME=2).bench(BSIZES=(2**7, 2**12, 2**14, 2**15,))
 
 def slow_bench():
-    b = Bencher(LRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 21)])
-    b = Bencher(LinkedListLRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 21)])
-    b = Bencher(SmallLRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 17)])
+    Bencher(cache.LRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 21)])
+    Bencher(cache.LinkedListLRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 21)])
+    Bencher(cache.SmallLRUCache, MAXTIME=5).bench(BSIZES=[2**x for x in range(7, 17)])
 
 MUCHADDINGSIZE=2**4
 MUCHADDINGNUM = 2**4
@@ -198,7 +198,7 @@ class Testy(unittest.TestCase):
         res = c.popitem()
         _assert(res == ("a", 1,), C, c, res)
         self.failUnless(res == ("a", 1,))
-            
+
     def _test_iterate_items(self, C):
         c = C({"a": 1})
         i = c.iteritems()
@@ -371,7 +371,7 @@ class Testy(unittest.TestCase):
         d.update(d2)
         self.failUnless(d._assert_invariants())
         self.failUnless(len(d) == 10)
-       
+
     def _test_LRU_overflow_on_init(self, C):
         d2 = {}
         for i in range(12):
@@ -381,7 +381,7 @@ class Testy(unittest.TestCase):
         self.failUnless(len(d) == 10)
 
     def _test_em(self):
-        for klass in (LRUCache, SmallLRUCache,):
+        for klass in (cache.LRUCache, cache.SmallLRUCache,):
             for testfunc in (self._test_empty_lookup, self._test_insert_and_get, self._test_insert_and_remove, self._test_extracted_bound_method, self._test_extracted_unbound_method, self._test_clear, self._test_update, self._test_setdefault,):
                 testfunc(klass())
 
@@ -390,7 +390,7 @@ class Testy(unittest.TestCase):
 
             self._test_unbound_method(klass, klass())
 
-        for klass in (LRUCache, SmallLRUCache,):
+        for klass in (cache.LRUCache, cache.SmallLRUCache,):
             for testfunc in (self._test_LRU_1, self._test_LRU_2, self._test_LRU_3, self._test_LRU_full, self._test_LRU_has_key, self._test_LRU_not_overfull_on_idempotent_add, self._test_LRU_overflow_on_update, self._test_LRU_overflow_on_init,):
                 testfunc(klass)
 
@@ -398,7 +398,7 @@ class Testy(unittest.TestCase):
         self._test_em()
 
     def _mem_test_LRU_much_adding_some_removing(self):
-        for klass in (LRUCache, SmallLRUCache,):
+        for klass in (cache.LRUCache, cache.SmallLRUCache,):
             return self._test_LRU_much_adding_some_removing(klass)
 
     def test_mem_leakage(self):
